Trait vapcore_network::client_version::ClientCapabilities [−][src]
Provide information about what a particular version of a peer software can do
Required methods
fn can_handle_large_requests(&self) -> bool[src]
Tetsy versions before TETSY_CLIENT_LARGE_REQUESTS_VERSION would not check the accumulated size of a packet when building a response to a GET_BLOCK_BODIES request. If the packet was larger than a given limit, instead of sending fewer blocks no packet would get sent at all. Query if this version can handle requests for a large number of block bodies.
fn accepts_service_transaction(&self) -> bool[src]
Service transactions are specific to tetsy. Query if this version accepts them.